<?php
/**
 * Aqeeq Agency Theme Customizer
 *
 * @package Aqeeq Agency
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function aqeeq_agency_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'aqeeq_agency_custom_controls' );

function aqeeq_agency_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
 
	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.logo .site-title a',
	 	'render_callback' => 'aqeeq_agency_Customize_partial_blogname',
	));

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => 'p.site-description',
		'render_callback' => 'aqeeq_agency_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'aqeeq_agency_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Homepage Settings', 'aqeeq-agency' ),
		'priority' => 10,
	));

	//Header
	$wp_customize->add_section( 'aqeeq_agency_header_section' , array(
    	'title' => __( 'Header Section', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_panel_id'
	) );

   	// Header Background color
	$wp_customize->add_setting('aqeeq_agency_header_background_color', array(
		'default'           => '#101010',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_header_background_color', array(
		'label'    => __('Header Background Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_header_section',
	)));

	$wp_customize->add_setting('aqeeq_agency_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','aqeeq-agency'),
		'section' => 'aqeeq_agency_header_section',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'aqeeq-agency' ),
			'center top'   => esc_html__( 'Top', 'aqeeq-agency' ),
			'right top'   => esc_html__( 'Top Right', 'aqeeq-agency' ),
			'left center'   => esc_html__( 'Left', 'aqeeq-agency' ),
			'center center'   => esc_html__( 'Center', 'aqeeq-agency' ),
			'right center'   => esc_html__( 'Right', 'aqeeq-agency' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'aqeeq-agency' ),
			'center bottom'   => esc_html__( 'Bottom', 'aqeeq-agency' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'aqeeq-agency' ),
		),
	));

	$wp_customize->add_setting('aqeeq_agency_header_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_header_btn_text',array(
		'label'	=> esc_html__('Add Button Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Get Free Quote', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_header_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_header_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('aqeeq_agency_header_btn_link',array(
		'label'	=> esc_html__('Add Button Link','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_header_section',
		'type'=> 'url'
	));

	//Menus Settings
	$wp_customize->add_section( 'aqeeq_agency_menu_section' , array(
    	'title' => __( 'Menus Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_panel_id'
	) );

	$wp_customize->add_setting('aqeeq_agency_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_navigation_menu_font_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','aqeeq-agency'),
        'section' => 'aqeeq_agency_menu_section',
        'choices' => array(
        	'100' => __('100','aqeeq-agency'),
            '200' => __('200','aqeeq-agency'),
            '300' => __('300','aqeeq-agency'),
            '400' => __('400','aqeeq-agency'),
            '500' => __('500','aqeeq-agency'),
            '600' => __('600','aqeeq-agency'),
            '700' => __('700','aqeeq-agency'),
            '800' => __('800','aqeeq-agency'),
            '900' => __('900','aqeeq-agency'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('aqeeq_agency_menu_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','aqeeq-agency'),
		'choices' => array(
            'Uppercase' => __('Uppercase','aqeeq-agency'),
            'Capitalize' => __('Capitalize','aqeeq-agency'),
            'Lowercase' => __('Lowercase','aqeeq-agency'),
        ),
		'section'=> 'aqeeq_agency_menu_section',
	));

	$wp_customize->add_setting('aqeeq_agency_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_menus_item_style',array(
        'type' => 'select',
        'section' => 'aqeeq_agency_menu_section',
		'label' => __('Menu Item Hover Style','aqeeq-agency'),
		'choices' => array(
            'None' => __('None','aqeeq-agency'),
            'Zoom In' => __('Zoom In','aqeeq-agency'),
        ),
	) );

	$wp_customize->add_setting('aqeeq_agency_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_header_menus_color', array(
		'label'    => __('Menus Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_menu_section',
	)));

	$wp_customize->add_setting('aqeeq_agency_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_menu_section',
	)));

	$wp_customize->add_setting('aqeeq_agency_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_menu_section',
	)));

	$wp_customize->add_setting('aqeeq_agency_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_menu_section',
	)));

	//Slider
	$wp_customize->add_section( 'aqeeq_agency_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'aqeeq-agency' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/aqeeq-agency-wordpress-theme/">GET PRO</a>','aqeeq-agency'),
		'panel' => 'aqeeq_agency_panel_id'
	) );

	$wp_customize->add_setting( 'aqeeq_agency_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','aqeeq-agency' ),
      'section' => 'aqeeq_agency_slidersettings'
    )));

    $wp_customize->add_setting('aqeeq_agency_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	) );
	$wp_customize->add_control('aqeeq_agency_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','aqeeq-agency'),
        'section' => 'aqeeq_agency_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','aqeeq-agency'),
            'Advance slider' => __('Advance slider','aqeeq-agency'),
        ),
	));

	$wp_customize->add_setting('aqeeq_agency_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','aqeeq-agency'),
		'section'=> 'aqeeq_agency_slidersettings',
		'type'=> 'text',
		'active_callback' => 'aqeeq_agency_advance_slider'
	));

	$wp_customize->add_setting('aqeeq_agency_slidersmall_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_slidersmall_section_title',array(
		'label'	=> __('Add Slider Small Text','aqeeq-agency'),
		'section'=> 'aqeeq_agency_slidersettings',
		'type'=> 'text',
		'active_callback' => 'aqeeq_agency_default_slider'
	));

	$wp_customize->add_setting('aqeeq_agency_slider_button_text',array(
		'default'=> 'Know More',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( 'Know More', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_slidersettings',
		'type'=> 'text',
		'active_callback' => 'aqeeq_agency_default_slider'
	));

	$wp_customize->add_setting('aqeeq_agency_top_button_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('aqeeq_agency_top_button_url',array(
		'label'	=> __('Add Button URL','aqeeq-agency'),
		'section'	=> 'aqeeq_agency_slidersettings',
		'setting'	=> 'aqeeq_agency_top_button_url',
		'type'	=> 'url',
		'active_callback' => 'aqeeq_agency_default_slider'
	));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('aqeeq_agency_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'aqeeq_agency_customize_partial_aqeeq_agency_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'aqeeq_agency_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'aqeeq_agency_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'aqeeq_agency_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'aqeeq-agency' ),
			'description' => __('Slider image size (1400 x 550)','aqeeq-agency'),
			'section'  => 'aqeeq_agency_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'aqeeq_agency_default_slider'
		) );
	}

	$wp_customize->add_setting( 'aqeeq_agency_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','aqeeq-agency'),
		'section' => 'aqeeq_agency_slidersettings',
		'type'  => 'text',
		'active_callback' => 'aqeeq_agency_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('aqeeq_agency_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_slider_height',array(
		'label'	=> __('Slider Height','aqeeq-agency'),
		'description'	=> __('Specify the slider height (px).','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_slidersettings',
		'type'=> 'text',
		'active_callback' => 'aqeeq_agency_default_slider'
	));

	//Opacity
	$wp_customize->add_setting('aqeeq_agency_slider_opacity_color',array(
      'default'              => 0.8,
      'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));

	$wp_customize->add_control( 'aqeeq_agency_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_slidersettings',
		'type'        => 'select',
		'settings'    => 'aqeeq_agency_slider_opacity_color',
		'choices' => array(
	      '0' =>  esc_attr('0','aqeeq-agency'),
	      '0.1' =>  esc_attr('0.1','aqeeq-agency'),
	      '0.2' =>  esc_attr('0.2','aqeeq-agency'),
	      '0.3' =>  esc_attr('0.3','aqeeq-agency'),
	      '0.4' =>  esc_attr('0.4','aqeeq-agency'),
	      '0.5' =>  esc_attr('0.5','aqeeq-agency'),
	      '0.6' =>  esc_attr('0.6','aqeeq-agency'),
	      '0.7' =>  esc_attr('0.7','aqeeq-agency'),
	      '0.8' =>  esc_attr('0.8','aqeeq-agency'),
	      '0.9' =>  esc_attr('0.9','aqeeq-agency')
	),'active_callback' => 'aqeeq_agency_default_slider'
	));

	$wp_customize->add_setting( 'aqeeq_agency_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
   ));
   $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_slider_image_overlay',array(
      	'label' => esc_html__( 'Show / Hide Slider Image Overlay','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_slidersettings',
      	'active_callback' => 'aqeeq_agency_default_slider'
   )));

   $wp_customize->add_setting('aqeeq_agency_slider_image_overlay_color', array(
		'default'           => '#000000',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_slidersettings',
		'active_callback' => 'aqeeq_agency_default_slider'
	)));

	$wp_customize->add_setting( 'aqeeq_agency_slider_arrow_hide_show',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	));
	$wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_slider_arrow_hide_show',array(
		'label' => esc_html__( 'Show / Hide Slider Arrows','aqeeq-agency' ),
		'section' => 'aqeeq_agency_slidersettings',
		'active_callback' => 'aqeeq_agency_default_slider'
	)));

	//About Us Section
	$wp_customize->add_section('aqeeq_agency_about', array(
		'title'       => __('About Us Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_about_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_about_text',array(
		'description' => __('<p>1. More options for about us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about us section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_about',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_about_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_about_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_about',
		'type'=> 'hidden'
	));

	//Join Now Section
	$wp_customize->add_section('aqeeq_agency_Join_now', array(
		'title'       => __('Join Now Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_Join_now_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_Join_now_text',array(
		'description' => __('<p>1. More options for Join now section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Join now section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_Join_now',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_Join_now_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_Join_now_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_Join_now',
		'type'=> 'hidden'
	));

	//Services Section
	$wp_customize->add_section('aqeeq_agency_services', array(
		'title'       => __('Services Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_services_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_services_text',array(
		'description' => __('<p>1. More options for services section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for services section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_services',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_services_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_services_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_services',
		'type'=> 'hidden'
	));

	//Project Work Section
	$wp_customize->add_section('aqeeq_agency_project_work', array(
		'title'       => __('Project Work Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_project_work_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_project_work_text',array(
		'description' => __('<p>1. More options for project work section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for project work section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_project_work',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_project_work_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_project_work_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_project_work',
		'type'=> 'hidden'
	));

	// Features Section
	$wp_customize->add_section('aqeeq_agency_features_section',array(
		'title'	=> __('Features Section','aqeeq-agency'),
		'description' => __('For more options of features section <br/> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/aqeeq-agency-wordpress-theme/">GET PRO</a> <br/><br/> Add section title and select the category to display for features post','aqeeq-agency'),
		'panel' => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting( 'aqeeq_agency_features_small_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_features_small_title', array(
		'label'    => __( 'Add Section Small Title', 'aqeeq-agency' ),
		'input_attrs' => array(
            'placeholder' => __( 'OUR FEATURES', 'aqeeq-agency' ),
        ),
		'section'  => 'aqeeq_agency_features_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'aqeeq_agency_features_heading', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_features_heading', array(
		'label'    => __( 'Add Section Heading', 'aqeeq-agency' ),
		'input_attrs' => array(
            'placeholder' => __( 'UNIQUE SOLUTIONS FOR YOUR PROBLEM', 'aqeeq-agency' ),
        ),
		'section'  => 'aqeeq_agency_features_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'aqeeq_agency_featured_content', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'aqeeq_agency_featured_content', array(
		'label'    => __( 'Add Section Content', 'aqeeq-agency' ),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem Ipsum Dolor Sit Amet', 'aqeeq-agency' ),
        ),
		'section'  => 'aqeeq_agency_features_section',
		'type'     => 'text'
	) );

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('aqeeq_agency_features_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'aqeeq_agency_sanitize_choices',
	));
	$wp_customize->add_control('aqeeq_agency_features_category',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Features Post','aqeeq-agency'),
		'section' => 'aqeeq_agency_features_section',
	));

	//Pricing Plan Section
	$wp_customize->add_section('aqeeq_agency_pricing_plan', array(
		'title'       => __('Pricing Plan Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_pricing_plan_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_pricing_plan_text',array(
		'description' => __('<p>1. More options for pricing plan section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for pricing plan section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_pricing_plan',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_pricing_plan_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_pricing_plan_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_pricing_plan',
		'type'=> 'hidden'
	));

	//Sponsor Section
	$wp_customize->add_section('aqeeq_agency_sponsor', array(
		'title'       => __('Sponsor Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_sponsor_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_sponsor_text',array(
		'description' => __('<p>1. More options for sponsor section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for sponsor section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_sponsor',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_sponsor_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_sponsor_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_sponsor',
		'type'=> 'hidden'
	));

	//Team Section
	$wp_customize->add_section('aqeeq_agency_team', array(
		'title'       => __('Team Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_team_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_team_text',array(
		'description' => __('<p>1. More options for team section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for team section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_team',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_team_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_team_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_team',
		'type'=> 'hidden'
	));

	//Testimonial Section
	$wp_customize->add_section('aqeeq_agency_testimonial', array(
		'title'       => __('Testimonial Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_testimonial_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_testimonial_text',array(
		'description' => __('<p>1. More options for testimonial section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonial section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_testimonial',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_testimonial_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_testimonial_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_testimonial',
		'type'=> 'hidden'
	));

	//Feature Skill Section
	$wp_customize->add_section('aqeeq_agency_feature_skill', array(
		'title'       => __('Feature Skill Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_feature_skill_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_feature_skill_text',array(
		'description' => __('<p>1. More options for feature skill section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for feature skill section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_feature_skill',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_feature_skill_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_feature_skill_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_feature_skill',
		'type'=> 'hidden'
	));

	//Counter Section
	$wp_customize->add_section('aqeeq_agency_counter', array(
		'title'       => __('Counter Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_counter_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_counter_text',array(
		'description' => __('<p>1. More options for counter section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for counter section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_counter',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_counter_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_counter_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_counter',
		'type'=> 'hidden'
	));

	//Blog Section
	$wp_customize->add_section('aqeeq_agency_blog', array(
		'title'       => __('Blog Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_blog_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_blog_text',array(
		'description' => __('<p>1. More options for blog section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for blog section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_blog',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_blog_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_blog_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_blog',
		'type'=> 'hidden'
	));

	//Newsletter Section
	$wp_customize->add_section('aqeeq_agency_newsletter', array(
		'title'       => __('Newsletter Section', 'aqeeq-agency'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','aqeeq-agency'),
		'priority'    => null,
		'panel'       => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting('aqeeq_agency_newsletter_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_newsletter_text',array(
		'description' => __('<p>1. More options for newsletter section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for newsletter section.</p>','aqeeq-agency'),
		'section'=> 'aqeeq_agency_newsletter',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('aqeeq_agency_newsletter_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_newsletter_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=aqeeq_agency_guide') ." '>More Info</a>",
		'section'=> 'aqeeq_agency_newsletter',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('aqeeq_agency_footer',array(
		'title'	=> esc_html__('Footer Settings','aqeeq-agency'),
		'description' => __('For more options of footer section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/aqeeq-agency-wordpress-theme/">GET PRO</a>','aqeeq-agency'),
		'panel' => 'aqeeq_agency_panel_id',
	));

	$wp_customize->add_setting( 'aqeeq_agency_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','aqeeq-agency' ),
      'section' => 'aqeeq_agency_footer'
    )));

 	// font size
	$wp_customize->add_setting('aqeeq_agency_button_footer_font_size',array(
		'default'=> 30,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','aqeeq-agency'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'aqeeq_agency_footer',
	));

	$wp_customize->add_setting('aqeeq_agency_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','aqeeq-agency'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'aqeeq_agency_footer',
	));

	// text trasform
	$wp_customize->add_setting('aqeeq_agency_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','aqeeq-agency'),
		'choices' => array(
      'Uppercase' => __('Uppercase','aqeeq-agency'),
      'Capitalize' => __('Capitalize','aqeeq-agency'),
      'Lowercase' => __('Lowercase','aqeeq-agency'),
    ),
		'section'=> 'aqeeq_agency_footer',
	));

	$wp_customize->add_setting('aqeeq_agency_footer_heading_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','aqeeq-agency'),
        'section' => 'aqeeq_agency_footer',
        'choices' => array(
        	'100' => __('100','aqeeq-agency'),
            '200' => __('200','aqeeq-agency'),
            '300' => __('300','aqeeq-agency'),
            '400' => __('400','aqeeq-agency'),
            '500' => __('500','aqeeq-agency'),
            '600' => __('600','aqeeq-agency'),
            '700' => __('700','aqeeq-agency'),
            '800' => __('800','aqeeq-agency'),
            '900' => __('900','aqeeq-agency'),
        ),
	) );


	$wp_customize->add_setting('aqeeq_agency_footer_template',array(
	  'default'	=> esc_html('aqeeq_agency-footer-one'),
	  'sanitize_callback'	=> 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_footer_template',array(
	      'label'	=> esc_html__('Footer style','aqeeq-agency'),
	      'section'	=> 'aqeeq_agency_footer',
	      'setting'	=> 'aqeeq_agency_footer_template',
	      'type' => 'select',
	      'choices' => array(
	          'aqeeq_agency-footer-one' => esc_html__('Style 1', 'aqeeq-agency'),
	          'aqeeq_agency-footer-two' => esc_html__('Style 2', 'aqeeq-agency'),
	          'aqeeq_agency-footer-three' => esc_html__('Style 3', 'aqeeq-agency'),
	          'aqeeq_agency-footer-four' => esc_html__('Style 4', 'aqeeq-agency'),
	          'aqeeq_agency-footer-five' => esc_html__('Style 5', 'aqeeq-agency'),
	          )
	));
  
	$wp_customize->add_setting('aqeeq_agency_footer_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_footer_background_color', array(
		'label'    => __('Footer Background Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_footer',
	)));

	$wp_customize->add_setting('aqeeq_agency_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'aqeeq_agency_footer_background_image',array(
        'label' => __('Footer Background Image','aqeeq-agency'),
        'section' => 'aqeeq_agency_footer'
	)));

	// Footer
	$wp_customize->add_setting('aqeeq_agency_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','aqeeq-agency'),
		'choices' => array(
            'fixed' => __('fixed','aqeeq-agency'),
            'scroll' => __('scroll','aqeeq-agency'),
        ),
		'section'=> 'aqeeq_agency_footer',
	));

	$wp_customize->add_setting('aqeeq_agency_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','aqeeq-agency'),
        'section' => 'aqeeq_agency_footer',
        'choices' => array(
        	'Left' => __('Left','aqeeq-agency'),
            'Center' => __('Center','aqeeq-agency'),
            'Right' => __('Right','aqeeq-agency')
        ),
	) );

	$wp_customize->add_setting('aqeeq_agency_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','aqeeq-agency'),
        'section' => 'aqeeq_agency_footer',
        'choices' => array(
        	'Left' => __('Left','aqeeq-agency'),
            'Center' => __('Center','aqeeq-agency'),
            'Right' => __('Right','aqeeq-agency')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('aqeeq_agency_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'aqeeq-agency' ),
    ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_footer_text', array(
		'selector' => '.copyright p',
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_footer_text',
	));

	$wp_customize->add_setting( 'aqeeq_agency_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','aqeeq-agency' ),
      'section' => 'aqeeq_agency_footer'
    )));

	$wp_customize->add_setting('aqeeq_agency_copyright_background_color', array(
		'default'           => '#ff44b6',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_footer',
	)));

	$wp_customize->add_setting('aqeeq_agency_copyright_text_color', array(
		'default'           => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_copyright_text_color', array(
		'label'    => __('Copyright Text Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_footer',
	)));

	$wp_customize->add_setting('aqeeq_agency_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_footer_text',array(
		'label'	=> esc_html__('Copyright Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_copyright_font_weight',array(
	  'default' => 400,
	  'transport' => 'refresh',
	  'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_copyright_font_weight',array(
	    'type' => 'select',
	    'label' => __('Copyright Font Weight','aqeeq-agency'),
	    'section' => 'aqeeq_agency_footer',
	    'choices' => array(
	    	'100' => __('100','aqeeq-agency'),
	        '200' => __('200','aqeeq-agency'),
	        '300' => __('300','aqeeq-agency'),
	        '400' => __('400','aqeeq-agency'),
	        '500' => __('500','aqeeq-agency'),
	        '600' => __('600','aqeeq-agency'),
	        '700' => __('700','aqeeq-agency'),
	        '800' => __('800','aqeeq-agency'),
	        '900' => __('900','aqeeq-agency'),
    ),
	));

	$wp_customize->add_setting('aqeeq_agency_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control(new Aqeeq_Agency_Image_Radio_Control($wp_customize, 'aqeeq_agency_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','aqeeq-agency'),
        'section' => 'aqeeq_agency_footer',
        'settings' => 'aqeeq_agency_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'aqeeq_agency_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_scroll_to_top_icon', array(
		'selector' => '.scrollup i',
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_scroll_to_top_icon',
	));

	$wp_customize->add_setting('aqeeq_agency_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_scroll_to_top_width',array(
		'label'	=> __('Icon Width','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_scroll_to_top_height',array(
		'label'	=> __('Icon Height','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_footer',
		'type'=> 'text'
	));

	//Blog Post
	$wp_customize->add_panel( 'aqeeq_agency_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'aqeeq_agency_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('aqeeq_agency_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
    ));
    $wp_customize->add_control(new Aqeeq_Agency_Image_Radio_Control($wp_customize, 'aqeeq_agency_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Post Layouts','aqeeq-agency'),
        'section' => 'aqeeq_agency_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	$wp_customize->add_setting('aqeeq_agency_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','aqeeq-agency'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','aqeeq-agency'),
        'section' => 'aqeeq_agency_post_settings',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','aqeeq-agency'),
            'Right Sidebar' => esc_html__('Right Sidebar','aqeeq-agency'),
            'One Column' => esc_html__('One Column','aqeeq-agency'),
			'Three Columns' => __('Three Columns','aqeeq-agency'),
			'Four Columns' => __('Four Columns','aqeeq-agency'),
            'Grid Layout' => esc_html__('Grid Layout','aqeeq-agency')
        ),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_toggle_postdate', array(
		'selector' => '.post-main-box h2 a',
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_toggle_postdate',
	));

	$wp_customize->add_setting( 'aqeeq_agency_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','aqeeq-agency' ),
        'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range'
	) );
	$wp_customize->add_control( 'aqeeq_agency_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'aqeeq_agency_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range'
	) );
	$wp_customize->add_control( 'aqeeq_agency_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('aqeeq_agency_blog_post_featured_image_dimension',array(
       'default' => 'default',
       'sanitize_callback'	=> 'aqeeq_agency_sanitize_choices'
	));
  	$wp_customize->add_control('aqeeq_agency_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','aqeeq-agency'),
		'section'	=> 'aqeeq_agency_post_settings',
		'choices' => array(
		'default' => __('Default','aqeeq-agency'),
		'custom' => __('Custom Image Size','aqeeq-agency'),
      ),
  	));

	$wp_customize->add_setting('aqeeq_agency_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('aqeeq_agency_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'aqeeq-agency' ),),
		'section'=> 'aqeeq_agency_post_settings',
		'type'=> 'text',
		'active_callback' => 'aqeeq_agency_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('aqeeq_agency_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'aqeeq-agency' ),),
		'section'=> 'aqeeq_agency_post_settings',
		'type'=> 'text',
		'active_callback' => 'aqeeq_agency_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'aqeeq_agency_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'aqeeq_agency_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_post_settings',
		'type'        => 'range',
		'settings'    => 'aqeeq_agency_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('aqeeq_agency_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','aqeeq-agency'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','aqeeq-agency'),
		'section'=> 'aqeeq_agency_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('aqeeq_agency_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','aqeeq-agency'),
        'section' => 'aqeeq_agency_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','aqeeq-agency'),
            'Excerpt' => esc_html__('Excerpt','aqeeq-agency'),
            'No Content' => esc_html__('No Content','aqeeq-agency')
        ),
	) );

   	$wp_customize->add_setting('aqeeq_agency_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','aqeeq-agency'),
        'section' => 'aqeeq_agency_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','aqeeq-agency'),
            'Without Blocks' => __('Without Blocks','aqeeq-agency')
        ),
	) );

	$wp_customize->add_setting( 'aqeeq_agency_blog_pagination_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_blog_pagination_hide_show',array(
		'label' => esc_html__( 'Show / Hide Blog Pagination','aqeeq-agency' ),
		'section' => 'aqeeq_agency_post_settings'
    )));

	$wp_customize->add_setting('aqeeq_agency_blog_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_blog_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_post_settings',
		'type'=> 'text'
	));
    
    // Button Settings
	$wp_customize->add_section( 'aqeeq_agency_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_button_text', array(
		'selector' => '.post-main-box .more-btn a',
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_button_text',
	));

    $wp_customize->add_setting('aqeeq_agency_button_text',array(
		'default'=> esc_html__('Read More','aqeeq-agency'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_text',array(
		'label'	=> esc_html__('Add Button Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('aqeeq_agency_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_font_size',array(
		'label'	=> __('Button Font Size','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'aqeeq-agency' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'aqeeq_agency_button_settings',
	));

	// button padding
	$wp_customize->add_setting('aqeeq_agency_button_top_bottom_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_top_bottom_padding',array(
		'label'	=> __('Button Top Bottom Padding','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'aqeeq-agency' ),
    ),
		'section'=> 'aqeeq_agency_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_button_left_right_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_left_right_padding',array(
		'label'	=> __('Button Left Right Padding','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'aqeeq-agency' ),
    ),
		'section'=> 'aqeeq_agency_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'aqeeq-agency' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'aqeeq_agency_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('aqeeq_agency_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','aqeeq-agency'),
		'choices' => array(
      'Uppercase' => __('Uppercase','aqeeq-agency'),
      'Capitalize' => __('Capitalize','aqeeq-agency'),
      'Lowercase' => __('Lowercase','aqeeq-agency'),
    ),
		'section'=> 'aqeeq_agency_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'aqeeq_agency_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('aqeeq_agency_related_post_title', array(
		'selector' => '.related-post h3',
		'render_callback' => 'aqeeq_agency_Customize_partial_aqeeq_agency_related_post_title',
	));

    $wp_customize->add_setting( 'aqeeq_agency_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','aqeeq-agency' ),
		'section' => 'aqeeq_agency_related_posts_settings'
    )));

    $wp_customize->add_setting('aqeeq_agency_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('aqeeq_agency_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'aqeeq_agency_sanitize_number_absint'
	));
	$wp_customize->add_control('aqeeq_agency_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'aqeeq_agency_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range'
	) );
	$wp_customize->add_control( 'aqeeq_agency_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'aqeeq_agency_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'aqeeq_agency_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

   	$wp_customize->add_setting( 'aqeeq_agency_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	) );
	$wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','aqeeq-agency' ),
	   'section' => 'aqeeq_agency_single_blog_settings'
	)));

    $wp_customize->add_setting( 'aqeeq_agency_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	) );
	$wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','aqeeq-agency' ),
	    'section' => 'aqeeq_agency_single_blog_settings'
	)));

	$wp_customize->add_setting( 'aqeeq_agency_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	) );
	$wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','aqeeq-agency' ),
	    'section' => 'aqeeq_agency_single_blog_settings'
	)));

	$wp_customize->add_setting( 'aqeeq_agency_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	) );
	$wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_time',array(
	    'label' => esc_html__( 'Show / Hide Time','aqeeq-agency' ),
	    'section' => 'aqeeq_agency_single_blog_settings'
	)));

	$wp_customize->add_setting( 'aqeeq_agency_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','aqeeq-agency' ),
		'section' => 'aqeeq_agency_single_blog_settings'
    )));

   	$wp_customize->add_setting( 'aqeeq_agency_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','aqeeq-agency' ),
		'section' => 'aqeeq_agency_single_blog_settings'
    )));

    // Single Posts Category
  	$wp_customize->add_setting( 'aqeeq_agency_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','aqeeq-agency' ),
		'section' => 'aqeeq_agency_single_blog_settings'
    )));

	$wp_customize->add_setting( 'aqeeq_agency_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
	));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Show / Hide Post Navigation','aqeeq-agency' ),
		'section' => 'aqeeq_agency_single_blog_settings'
    )));

   	$wp_customize->add_setting('aqeeq_agency_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','aqeeq-agency'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','aqeeq-agency'),
		'section'=> 'aqeeq_agency_single_blog_settings',
		'type'=> 'text'
	));

	//navigation text
	$wp_customize->add_setting('aqeeq_agency_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_single_blog_comment_title',array(
		'default'=> 'Leave a Reply',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('aqeeq_agency_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','aqeeq-agency'),
		'input_attrs' => array(
        'placeholder' => __( 'Leave a Reply', 'aqeeq-agency' ),
    	),
		'section'=> 'aqeeq_agency_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_single_blog_comment_button_text',array(
		'default'=> 'Post Comment',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('aqeeq_agency_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','aqeeq-agency'),
		'description'	=> __('Enter a value in %. Example:50%','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_single_blog_settings',
		'type'=> 'text'
	));
	
    // Grid layout setting
	$wp_customize->add_section( 'aqeeq_agency_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'aqeeq_agency_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','aqeeq-agency' ),
        'section' => 'aqeeq_agency_grid_layout_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','aqeeq-agency' ),
		'section' => 'aqeeq_agency_grid_layout_settings'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','aqeeq-agency' ),
		'section' => 'aqeeq_agency_grid_layout_settings'
    )));

	$wp_customize->add_setting('aqeeq_agency_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','aqeeq-agency'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','aqeeq-agency'),
		'section'=> 'aqeeq_agency_grid_layout_settings',
		'type'=> 'text'
	));

	 $wp_customize->add_setting( 'aqeeq_agency_grid_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'aqeeq_agency_grid_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_grid_layout_settings',
		'type'        => 'range',
		'settings'    => 'aqeeq_agency_grid_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

  	$wp_customize->add_setting('aqeeq_agency_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','aqeeq-agency'),
	    'section' => 'aqeeq_agency_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','aqeeq-agency'),
  		    'Without Blocks' => __('Without Blocks','aqeeq-agency')
      	),
	) );

	$wp_customize->add_setting('aqeeq_agency_grid_button_text',array(
		'default'=> esc_html__('Read More','aqeeq-agency'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','aqeeq-agency'),
		'input_attrs' => array(
        'placeholder' => esc_html__( 'Read More', 'aqeeq-agency' ),
      ),
		'section'=> 'aqeeq_agency_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_grid_layout_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('aqeeq_agency_grid_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_grid_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Grid Post Content','aqeeq-agency'),
        'section' => 'aqeeq_agency_grid_layout_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','aqeeq-agency'),
            'Excerpt' => esc_html__('Excerpt','aqeeq-agency'),
            'No Content' => esc_html__('No Content','aqeeq-agency')
        ),
	) );

    $wp_customize->add_setting( 'aqeeq_agency_grid_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range'
	) );
	$wp_customize->add_control( 'aqeeq_agency_grid_featured_image_border_radius', array(
		'label'       => esc_html__( 'Grid Featured Image Border Radius','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_grid_layout_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'aqeeq_agency_grid_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range'
	) );
	$wp_customize->add_control( 'aqeeq_agency_grid_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Grid Featured Image Box Shadow','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_grid_layout_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );


	//Other Settings
	$wp_customize->add_panel( 'aqeeq_agency_blog_other_panel', array(
		'title' => esc_html__( 'Other Settings', 'aqeeq-agency' ),
		'panel' => 'aqeeq_agency_panel_id',
		'priority' => 20,
	));

	// Layout
	$wp_customize->add_section( 'aqeeq_agency_left_right', array(
    	'title' => esc_html__('General Settings', 'aqeeq-agency'),
		'panel' => 'aqeeq_agency_blog_other_panel'
	) );

	$wp_customize->add_setting('aqeeq_agency_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control(new Aqeeq_Agency_Image_Radio_Control($wp_customize, 'aqeeq_agency_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','aqeeq-agency'),
        'description' => esc_html__('Here you can change the width layout of Website.','aqeeq-agency'),
        'section' => 'aqeeq_agency_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('aqeeq_agency_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','aqeeq-agency'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','aqeeq-agency'),
        'section' => 'aqeeq_agency_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','aqeeq-agency'),
            'Right_Sidebar' => esc_html__('Right Sidebar','aqeeq-agency'),
            'One_Column' => esc_html__('One Column','aqeeq-agency')
        ),
	) );

    //404 Page Setting
	$wp_customize->add_section('aqeeq_agency_404_page',array(
		'title'	=> __('404 Page Settings','aqeeq-agency'),
		'panel' => 'aqeeq_agency_others_panel',
	));

	$wp_customize->add_setting('aqeeq_agency_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('aqeeq_agency_404_page_title',array(
		'label'	=> __('Add Title','aqeeq-agency'),
		'input_attrs' => array(
    'placeholder' => __( '404 Not Found', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('aqeeq_agency_404_page_content',array(
		'label'	=> __('Add Text','aqeeq-agency'),
		'input_attrs' => array(
    'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_404_page_button_text',array(
		'label'	=> __('Add Button Text','aqeeq-agency'),
		'input_attrs' => array(
    'placeholder' => __( 'Return to the home page', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_404_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('aqeeq_agency_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','aqeeq-agency'),
		'panel' => 'aqeeq_agency_others_panel',
	));

	$wp_customize->add_setting('aqeeq_agency_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_social_icon_padding',array(
		'label'	=> __('Icon Padding','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_social_icon_width',array(
		'label'	=> __('Icon Width','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('aqeeq_agency_social_icon_height',array(
		'label'	=> __('Icon Height','aqeeq-agency'),
		'description'	=> __('Enter a value in pixels. Example:20px','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_social_icon_settings',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('aqeeq_agency_no_results_page',array(
		'title'	=> __('No Results Page Settings','aqeeq-agency'),
		'panel' => 'aqeeq_agency_others_panel',
	));

	$wp_customize->add_setting('aqeeq_agency_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('aqeeq_agency_no_results_page_title',array(
		'label'	=> __('Add Title','aqeeq-agency'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('aqeeq_agency_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('aqeeq_agency_no_results_page_content',array(
		'label'	=> __('Add Text','aqeeq-agency'),
		'input_attrs' => array(
    'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'aqeeq-agency' ),
        ),
		'section'=> 'aqeeq_agency_no_results_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('aqeeq_agency_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','aqeeq-agency'),
		'panel' => 'aqeeq_agency_blog_other_panel',
	));

    $wp_customize->add_setting( 'aqeeq_agency_resp_slider_hide_show',array(
      	'default' => 1,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_responsive_media'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_responsive_media'
    )));

    $wp_customize->add_setting( 'aqeeq_agency_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','aqeeq-agency' ),
      	'section' => 'aqeeq_agency_responsive_media'
    )));

    $wp_customize->add_setting('aqeeq_agency_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_responsive_media',
	)));

    $wp_customize->add_setting( 'aqeeq_agency_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','aqeeq-agency' ),
		'section' => 'aqeeq_agency_left_right'
    )));

    //Wow Animation
	$wp_customize->add_setting( 'aqeeq_agency_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ));
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_animation',array(
        'label' => esc_html__( 'Show / Hide Animations','aqeeq-agency' ),
        'description' => __('Here you can disable overall site animation effect','aqeeq-agency'),
        'section' => 'aqeeq_agency_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'aqeeq_agency_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','aqeeq-agency' ),
        'section' => 'aqeeq_agency_left_right'
    )));

	$wp_customize->add_setting('aqeeq_agency_preloader_bg_color', array(
		'default'           => '#ff44b6',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_left_right',
	)));

	$wp_customize->add_setting('aqeeq_agency_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'aqeeq_agency_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'aqeeq-agency'),
		'section'  => 'aqeeq_agency_left_right',
	)));

	$wp_customize->add_setting('aqeeq_agency_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'aqeeq_agency_preloader_bg_img',array(
        'label' => __('Preloader Background Image','aqeeq-agency'),
        'section' => 'aqeeq_agency_left_right'
	)));

    //Woocommerce settings
	$wp_customize->add_section('aqeeq_agency_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'aqeeq-agency'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    //Shop Page Featured Image
	$wp_customize->add_setting( 'aqeeq_agency_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range'
	) );
	$wp_customize->add_control( 'aqeeq_agency_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'aqeeq_agency_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'aqeeq_agency_sanitize_number_range'
	) );
	$wp_customize->add_control( 'aqeeq_agency_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','aqeeq-agency' ),
		'section'     => 'aqeeq_agency_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'aqeeq_agency_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar',
		'render_callback' => 'aqeeq_agency_customize_partial_aqeeq_agency_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'aqeeq_agency_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','aqeeq-agency' ),
		'section' => 'aqeeq_agency_woocommerce_section'
    )));

    $wp_customize->add_setting('aqeeq_agency_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','aqeeq-agency'),
        'section' => 'aqeeq_agency_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','aqeeq-agency'),
            'Right Sidebar' => __('Right Sidebar','aqeeq-agency'),
        ),
	) );

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'aqeeq_agency_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar',
		'render_callback' => 'aqeeq_agency_customize_partial_aqeeq_agency_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'aqeeq_agency_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','aqeeq-agency' ),
		'section' => 'aqeeq_agency_woocommerce_section'
    )));

   	$wp_customize->add_setting('aqeeq_agency_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'aqeeq_agency_sanitize_choices'
	));
	$wp_customize->add_control('aqeeq_agency_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','aqeeq-agency'),
        'section' => 'aqeeq_agency_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','aqeeq-agency'),
            'Right Sidebar' => __('Right Sidebar','aqeeq-agency'),
        ),
	) );

  	// Related Product
    $wp_customize->add_setting( 'aqeeq_agency_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'aqeeq_agency_switch_sanitization'
    ) );
    $wp_customize->add_control( new Aqeeq_Agency_Toggle_Switch_Custom_Control( $wp_customize, 'aqeeq_agency_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related product','aqeeq-agency' ),
        'section' => 'aqeeq_agency_woocommerce_section'
    )));

}

add_action( 'customize_register', 'aqeeq_agency_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Aqeeq_Agency_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Aqeeq_Agency_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Aqeeq_Agency_Customize_Section_Pro( $manager,'aqeeq_agency_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'AQEEQ AGENCY PRO', 'aqeeq-agency' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'aqeeq-agency' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/aqeeq-agency-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Aqeeq_Agency_Customize_Section_Pro($manager,'aqeeq_agency_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'aqeeq-agency' ),
			'pro_text' => esc_html__( 'DOCS', 'aqeeq-agency' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-aqeeq-agency/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'aqeeq-agency-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'aqeeq-agency-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Aqeeq_Agency_Customize::get_instance();
